@@ -10,13 +10,15 @@ import psycopg2 as pg2
 import psycopg2.extras as pg2_extras
 
 # app
-from src.utils import notnull
+from .utils import notnull
 
-db = PostgresqlDatabase(host=notnull(getenv('POSTGRES_HOST')),
-                        port=notnull(getenv('POSTGRES_PORT')),
-                        database=notnull(getenv('POSTGRES_DBNAME')),
-                        user=notnull(getenv('POSTGRES_USER')),
-                        password=notnull(getenv('POSTGRES_PASSWORD')))
+db = PostgresqlDatabase(
+	host=notnull(getenv('POSTGRES_HOST')),
+	port=notnull(getenv('POSTGRES_PORT')),
+	database=notnull(getenv('POSTGRES_DBNAME')),
+	user=notnull(getenv('POSTGRES_USER')),
+	password=notnull(getenv('POSTGRES_PASSWORD'))
+)
 
 
 class User(Model):
@@ -65,7 +67,7 @@ class CampaignDataSources(Model):
 		db_table = 'campaign_data_source'
 		schema = 'core'
 		indexes = (
-		    (('campaign', 'data_source'), True),  # unique together
+			(('campaign', 'data_source'), True),  # unique together
 		)
 
 
@@ -78,7 +80,7 @@ class Supervisor(Model):
 		db_table = 'supervisor'
 		schema = 'core'
 		indexes = (
-		    (('campaign', 'user'), True),  # unique together
+			(('campaign', 'user'), True),  # unique together
 		)
 
 
@@ -94,7 +96,7 @@ class Participant(Model):
 		schema = 'core'
 
 		indexes = (
-		    (('campaign', 'user'), True),  # unique together
+			(('campaign', 'user'), True),  # unique together
 		)
 
 
@@ -110,13 +112,19 @@ class HourlyStats(Model):
 		schema = 'core'
 
 		indexes = (
-		    (('participant', 'data_source'), False),  # selection by participant and/or data source
-		    (('ts',), False),  # selection by timestamp
+			(('participant', 'data_source'), False),  # selection by participant and/or data source
+			(('ts',), False),  # selection by timestamp
 		)
 
 
 # create schema if necessary
-conn = pg2.connect(host=DB["default"]["HOST"], port=DB["default"]["PORT"], dbname=DB["default"]["NAME"], user=DB["default"]["USER"], password=DB["default"]["PASSWORD"])
+conn = pg2.connect(
+	host=notnull(getenv('POSTGRES_HOST')),
+	port=notnull(getenv('POSTGRES_PORT')),
+	dbname=notnull(getenv('POSTGRES_DBNAME')),
+	user=notnull(getenv('POSTGRES_USER')),
+	password=notnull(getenv('POSTGRES_PASSWORD'))
+)
 cur: pg2_extras.DictCursor = conn.cursor(cursor_factory=pg2_extras.DictCursor)
 cur.execute('create schema if not exists core')
 cur.execute('create schema if not exists data')
